From d9bd374b84fe72bf99cac958d0f80117e5ba59db Mon Sep 17 00:00:00 2001
From: chenhaozhe <cgz@hz-kingdee.com>
Date: 星期二, 24 二月 2026 15:46:01 +0800
Subject: [PATCH] 华舟 添加 模具出库、首件、巡检、末检、取样  消息推送 锦隆 金蝶云 新增 添加字段

---
 BLL/bin/Release/DAL.dll                                              |    0 
 DAL/bin/Release/DBUtility.dll                                        |    0 
 WebAPI/Controllers/MJGL/Sc_MouldUpperBillController.cs               |   11 ++
 DAL/bin/Release/Pub_Control.dll                                      |    0 
 DBUtility/bin/Release/Pub_Control.pdb                                |    0 
 WebAPI/Controllers/品质管理/巡检单/QC_PatrolProcCheckOtherBillController.cs |   22 +++++
 SyntacticSugar/bin/Debug/SyntacticSugar.pdb                          |    0 
 WebAPI/WebAPI.csproj.user                                            |    4 
 DAL/bin/Release/DBUtility.pdb                                        |    0 
 DAL/bin/Release/Model.dll                                            |    0 
 DBUtility/bin/Release/Pub_Class.dll                                  |    0 
 SyntacticSugar/obj/Debug/SyntacticSugar.dll                          |    0 
 DBUtility/bin/Release/Pub_Control.dll                                |    0 
 DAL/bin/Release/Pub_Control.pdb                                      |    0 
 DAL/bin/Release/DAL.pdb                                              |    0 
 Model/bin/Release/Pub_Control.pdb                                    |    0 
 BLL/bin/Release/Model.dll                                            |    0 
 BLL/bin/Release/DAL.pdb                                              |    0 
 Model/bin/Release/Pub_Class.pdb                                      |    0 
 BLL/bin/Release/Model.pdb                                            |    0 
 DAL/bin/Release/DAL.dll                                              |    0 
 SyntacticSugar/bin/Debug/SyntacticSugar.dll                          |    0 
 DAL/bin/Release/Model.pdb                                            |    0 
 sdk_dingding/TopSdk/bin/Debug/TopSdk.dll                             |    0 
 WebAPI/Controllers/品质管理/检验取样还样单/QC_TakeSampleCheckBillController.cs  |   12 ++
 Model/obj/Release/Model.pdb                                          |    0 
 BLL/bin/Release/BLL.pdb                                              |    0 
 DBUtility/bin/Release/DBUtility.pdb                                  |    0 
 DBUtility/bin/Release/DBUtility.dll                                  |    0 
 sdk_dingding/TopSdk/obj/Debug/TopSdk.dll                             |    0 
 Model/bin/Release/Pub_Control.dll                                    |    0 
 Pub_Control/bin/Release/Pub_Class.pdb                                |    0 
 sdk_dingding/TopSdk/obj/Debug/TopSdk.csproj.FileListAbsolute.txt     |    1 
 Pub_Control/bin/Release/Pub_Class.dll                                |    0 
 SyntacticSugar/obj/Debug/SyntacticSugar.pdb                          |    0 
 sdk_dingding/TopSdk/obj/Debug/TopSdk.pdb                             |    0 
 BLL/bin/Release/Pub_Control.pdb                                      |    0 
 Pub_Class/bin/Release/Pub_Class.pdb                                  |    0 
 Pub_Control/bin/Release/Pub_Control.dll                              |    0 
 BLL/bin/Release/DBUtility.pdb                                        |    0 
 Model/bin/Release/DBUtility.pdb                                      |    0 
 WebAPI/Controllers/条码管理/WEBSController.cs                            |   19 ++++
 SQLHelper/bin/Release/Pub_Class.pdb                                  |    0 
 WebAPI/Controllers/MJGL/Sc_MouldProdOutBillController.cs             |   23 +++++
 BLL/bin/Release/Pub_Control.dll                                      |    0 
 WebAPI/Controllers/LMESController.cs                                 |    1 
 Pub_Class/bin/Release/Pub_Class.dll                                  |    0 
 DBUtility/obj/Release/DBUtility.csproj.GenerateResource.Cache        |    0 
 SQLHelper/bin/Release/Pub_Class.dll                                  |    0 
 DBUtility/obj/Release/DBUtility.pdb                                  |    0 
 Model/bin/Release/DBUtility.dll                                      |    0 
 DAL/bin/Release/Pub_Class.pdb                                        |    0 
 BLL/bin/Release/DBUtility.dll                                        |    0 
 BLL/bin/Release/BLL.dll                                              |    0 
 Pub_Control/bin/Release/Pub_Control.pdb                              |    0 
 WebAPI/Controllers/品质管理/首件检验单/QC_FirstPieceCheckBillController.cs    |   13 ++
 DBUtility/obj/Release/DBUtility.dll                                  |    0 
 sdk_dingding/TopSdk/bin/Debug/TopSdk.pdb                             |    0 
 Model/obj/Release/Model.dll                                          |    0 
 BLL/bin/Release/Pub_Class.dll                                        |    0 
 Model/obj/Release/Model.csproj.AssemblyReference.cache               |    0 
 Model/bin/Release/Model.pdb                                          |    0 
 DAL/bin/Release/Pub_Class.dll                                        |    0 
 Model/bin/Release/Pub_Class.dll                                      |    0 
 Model/bin/Release/Model.dll                                          |    0 
 /dev/null                                                            |    0 
 DBUtility/bin/Release/Pub_Class.pdb                                  |    0 
 BLL/bin/Release/Pub_Class.pdb                                        |    0 
 WebAPI/Properties/PublishProfiles/FolderProfile4.pubxml.user         |   28 +++---
 WebAPI/Controllers/Sc_ProcessMangementController.cs                  |   29 ++++++
 WebAPI/Controllers/品质管理/工序检验单/QC_ProcessCheckBillController.cs       |   20 +++++
 71 files changed, 156 insertions(+), 27 deletions(-)

diff --git a/BLL/bin/Release/BLL.dll b/BLL/bin/Release/BLL.dll
index 43c4e0d..2723b0c 100644
--- a/BLL/bin/Release/BLL.dll
+++ b/BLL/bin/Release/BLL.dll
Binary files differ
diff --git a/BLL/bin/Release/BLL.pdb b/BLL/bin/Release/BLL.pdb
index 3245a2a..9a5414c 100644
--- a/BLL/bin/Release/BLL.pdb
+++ b/BLL/bin/Release/BLL.pdb
Binary files differ
diff --git a/BLL/bin/Release/DAL.dll b/BLL/bin/Release/DAL.dll
index 4d24e3c..4e4a321 100644
--- a/BLL/bin/Release/DAL.dll
+++ b/BLL/bin/Release/DAL.dll
Binary files differ
diff --git a/BLL/bin/Release/DAL.pdb b/BLL/bin/Release/DAL.pdb
index 3908ac8..7507e6f 100644
--- a/BLL/bin/Release/DAL.pdb
+++ b/BLL/bin/Release/DAL.pdb
Binary files differ
diff --git a/BLL/bin/Release/DBUtility.dll b/BLL/bin/Release/DBUtility.dll
index dbcd728..99eadb7 100644
--- a/BLL/bin/Release/DBUtility.dll
+++ b/BLL/bin/Release/DBUtility.dll
Binary files differ
diff --git a/BLL/bin/Release/DBUtility.pdb b/BLL/bin/Release/DBUtility.pdb
index e0c1c38..ad8433e 100644
--- a/BLL/bin/Release/DBUtility.pdb
+++ b/BLL/bin/Release/DBUtility.pdb
Binary files differ
diff --git a/BLL/bin/Release/Model.dll b/BLL/bin/Release/Model.dll
index 08b6913..4dce4a1 100644
--- a/BLL/bin/Release/Model.dll
+++ b/BLL/bin/Release/Model.dll
Binary files differ
diff --git a/BLL/bin/Release/Model.pdb b/BLL/bin/Release/Model.pdb
index 285e8cd..dc1bd4e 100644
--- a/BLL/bin/Release/Model.pdb
+++ b/BLL/bin/Release/Model.pdb
Binary files differ
diff --git a/BLL/bin/Release/Pub_Class.dll b/BLL/bin/Release/Pub_Class.dll
index 02c8a1d..b1e99a9 100644
--- a/BLL/bin/Release/Pub_Class.dll
+++ b/BLL/bin/Release/Pub_Class.dll
Binary files differ
diff --git a/BLL/bin/Release/Pub_Class.pdb b/BLL/bin/Release/Pub_Class.pdb
index 1ac7450..e80c2b9 100644
--- a/BLL/bin/Release/Pub_Class.pdb
+++ b/BLL/bin/Release/Pub_Class.pdb
Binary files differ
diff --git a/BLL/bin/Release/Pub_Control.dll b/BLL/bin/Release/Pub_Control.dll
index a887c85..bf24be6 100644
--- a/BLL/bin/Release/Pub_Control.dll
+++ b/BLL/bin/Release/Pub_Control.dll
Binary files differ
diff --git a/BLL/bin/Release/Pub_Control.pdb b/BLL/bin/Release/Pub_Control.pdb
index 4aa1260..d6e00c4 100644
--- a/BLL/bin/Release/Pub_Control.pdb
+++ b/BLL/bin/Release/Pub_Control.pdb
Binary files differ
diff --git a/DAL/bin/Release/DAL.dll b/DAL/bin/Release/DAL.dll
index 4d24e3c..4e4a321 100644
--- a/DAL/bin/Release/DAL.dll
+++ b/DAL/bin/Release/DAL.dll
Binary files differ
diff --git a/DAL/bin/Release/DAL.pdb b/DAL/bin/Release/DAL.pdb
index 3908ac8..7507e6f 100644
--- a/DAL/bin/Release/DAL.pdb
+++ b/DAL/bin/Release/DAL.pdb
Binary files differ
diff --git a/DAL/bin/Release/DBUtility.dll b/DAL/bin/Release/DBUtility.dll
index dbcd728..99eadb7 100644
--- a/DAL/bin/Release/DBUtility.dll
+++ b/DAL/bin/Release/DBUtility.dll
Binary files differ
diff --git a/DAL/bin/Release/DBUtility.pdb b/DAL/bin/Release/DBUtility.pdb
index e0c1c38..ad8433e 100644
--- a/DAL/bin/Release/DBUtility.pdb
+++ b/DAL/bin/Release/DBUtility.pdb
Binary files differ
diff --git a/DAL/bin/Release/Model.dll b/DAL/bin/Release/Model.dll
index 08b6913..4dce4a1 100644
--- a/DAL/bin/Release/Model.dll
+++ b/DAL/bin/Release/Model.dll
Binary files differ
diff --git a/DAL/bin/Release/Model.pdb b/DAL/bin/Release/Model.pdb
index 285e8cd..dc1bd4e 100644
--- a/DAL/bin/Release/Model.pdb
+++ b/DAL/bin/Release/Model.pdb
Binary files differ
diff --git a/DAL/bin/Release/Pub_Class.dll b/DAL/bin/Release/Pub_Class.dll
index 02c8a1d..b1e99a9 100644
--- a/DAL/bin/Release/Pub_Class.dll
+++ b/DAL/bin/Release/Pub_Class.dll
Binary files differ
diff --git a/DAL/bin/Release/Pub_Class.pdb b/DAL/bin/Release/Pub_Class.pdb
index 1ac7450..e80c2b9 100644
--- a/DAL/bin/Release/Pub_Class.pdb
+++ b/DAL/bin/Release/Pub_Class.pdb
Binary files differ
diff --git a/DAL/bin/Release/Pub_Control.dll b/DAL/bin/Release/Pub_Control.dll
index a887c85..bf24be6 100644
--- a/DAL/bin/Release/Pub_Control.dll
+++ b/DAL/bin/Release/Pub_Control.dll
Binary files differ
diff --git a/DAL/bin/Release/Pub_Control.pdb b/DAL/bin/Release/Pub_Control.pdb
index 4aa1260..d6e00c4 100644
--- a/DAL/bin/Release/Pub_Control.pdb
+++ b/DAL/bin/Release/Pub_Control.pdb
Binary files differ
diff --git a/DBUtility/bin/Release/DBUtility.dll b/DBUtility/bin/Release/DBUtility.dll
index dbcd728..99eadb7 100644
--- a/DBUtility/bin/Release/DBUtility.dll
+++ b/DBUtility/bin/Release/DBUtility.dll
Binary files differ
diff --git a/DBUtility/bin/Release/DBUtility.pdb b/DBUtility/bin/Release/DBUtility.pdb
index e0c1c38..ad8433e 100644
--- a/DBUtility/bin/Release/DBUtility.pdb
+++ b/DBUtility/bin/Release/DBUtility.pdb
Binary files differ
diff --git a/DBUtility/bin/Release/Pub_Class.dll b/DBUtility/bin/Release/Pub_Class.dll
index 02c8a1d..b1e99a9 100644
--- a/DBUtility/bin/Release/Pub_Class.dll
+++ b/DBUtility/bin/Release/Pub_Class.dll
Binary files differ
diff --git a/DBUtility/bin/Release/Pub_Class.pdb b/DBUtility/bin/Release/Pub_Class.pdb
index 1ac7450..e80c2b9 100644
--- a/DBUtility/bin/Release/Pub_Class.pdb
+++ b/DBUtility/bin/Release/Pub_Class.pdb
Binary files differ
diff --git a/DBUtility/bin/Release/Pub_Control.dll b/DBUtility/bin/Release/Pub_Control.dll
index a887c85..bf24be6 100644
--- a/DBUtility/bin/Release/Pub_Control.dll
+++ b/DBUtility/bin/Release/Pub_Control.dll
Binary files differ
diff --git a/DBUtility/bin/Release/Pub_Control.pdb b/DBUtility/bin/Release/Pub_Control.pdb
index 4aa1260..d6e00c4 100644
--- a/DBUtility/bin/Release/Pub_Control.pdb
+++ b/DBUtility/bin/Release/Pub_Control.pdb
Binary files differ
diff --git a/DBUtility/obj/Release/DBUtility.csproj.GenerateResource.Cache b/DBUtility/obj/Release/DBUtility.csproj.GenerateResource.Cache
index 521a5d0..4ddb16a 100644
--- a/DBUtility/obj/Release/DBUtility.csproj.GenerateResource.Cache
+++ b/DBUtility/obj/Release/DBUtility.csproj.GenerateResource.Cache
Binary files differ
diff --git a/DBUtility/obj/Release/DBUtility.dll b/DBUtility/obj/Release/DBUtility.dll
index dbcd728..99eadb7 100644
--- a/DBUtility/obj/Release/DBUtility.dll
+++ b/DBUtility/obj/Release/DBUtility.dll
Binary files differ
diff --git a/DBUtility/obj/Release/DBUtility.pdb b/DBUtility/obj/Release/DBUtility.pdb
index e0c1c38..ad8433e 100644
--- a/DBUtility/obj/Release/DBUtility.pdb
+++ b/DBUtility/obj/Release/DBUtility.pdb
Binary files differ
diff --git a/Model/bin/Release/DBUtility.dll b/Model/bin/Release/DBUtility.dll
index dbcd728..99eadb7 100644
--- a/Model/bin/Release/DBUtility.dll
+++ b/Model/bin/Release/DBUtility.dll
Binary files differ
diff --git a/Model/bin/Release/DBUtility.pdb b/Model/bin/Release/DBUtility.pdb
index e0c1c38..ad8433e 100644
--- a/Model/bin/Release/DBUtility.pdb
+++ b/Model/bin/Release/DBUtility.pdb
Binary files differ
diff --git a/Model/bin/Release/Model.dll b/Model/bin/Release/Model.dll
index 08b6913..4dce4a1 100644
--- a/Model/bin/Release/Model.dll
+++ b/Model/bin/Release/Model.dll
Binary files differ
diff --git a/Model/bin/Release/Model.pdb b/Model/bin/Release/Model.pdb
index 285e8cd..dc1bd4e 100644
--- a/Model/bin/Release/Model.pdb
+++ b/Model/bin/Release/Model.pdb
Binary files differ
diff --git a/Model/bin/Release/Pub_Class.dll b/Model/bin/Release/Pub_Class.dll
index 02c8a1d..b1e99a9 100644
--- a/Model/bin/Release/Pub_Class.dll
+++ b/Model/bin/Release/Pub_Class.dll
Binary files differ
diff --git a/Model/bin/Release/Pub_Class.pdb b/Model/bin/Release/Pub_Class.pdb
index 1ac7450..e80c2b9 100644
--- a/Model/bin/Release/Pub_Class.pdb
+++ b/Model/bin/Release/Pub_Class.pdb
Binary files differ
diff --git a/Model/bin/Release/Pub_Control.dll b/Model/bin/Release/Pub_Control.dll
index a887c85..bf24be6 100644
--- a/Model/bin/Release/Pub_Control.dll
+++ b/Model/bin/Release/Pub_Control.dll
Binary files differ
diff --git a/Model/bin/Release/Pub_Control.pdb b/Model/bin/Release/Pub_Control.pdb
index 4aa1260..d6e00c4 100644
--- a/Model/bin/Release/Pub_Control.pdb
+++ b/Model/bin/Release/Pub_Control.pdb
Binary files differ
diff --git a/Model/obj/Release/Model.csproj.AssemblyReference.cache b/Model/obj/Release/Model.csproj.AssemblyReference.cache
index 1eac65e..562d8b4 100644
--- a/Model/obj/Release/Model.csproj.AssemblyReference.cache
+++ b/Model/obj/Release/Model.csproj.AssemblyReference.cache
Binary files differ
diff --git a/Model/obj/Release/Model.dll b/Model/obj/Release/Model.dll
index 08b6913..4dce4a1 100644
--- a/Model/obj/Release/Model.dll
+++ b/Model/obj/Release/Model.dll
Binary files differ
diff --git a/Model/obj/Release/Model.pdb b/Model/obj/Release/Model.pdb
index 285e8cd..dc1bd4e 100644
--- a/Model/obj/Release/Model.pdb
+++ b/Model/obj/Release/Model.pdb
Binary files differ
diff --git a/Pub_Class/bin/Release/Pub_Class.dll b/Pub_Class/bin/Release/Pub_Class.dll
index 02c8a1d..b1e99a9 100644
--- a/Pub_Class/bin/Release/Pub_Class.dll
+++ b/Pub_Class/bin/Release/Pub_Class.dll
Binary files differ
diff --git a/Pub_Class/bin/Release/Pub_Class.pdb b/Pub_Class/bin/Release/Pub_Class.pdb
index 1ac7450..e80c2b9 100644
--- a/Pub_Class/bin/Release/Pub_Class.pdb
+++ b/Pub_Class/bin/Release/Pub_Class.pdb
Binary files differ
diff --git a/Pub_Control/bin/Release/Pub_Class.dll b/Pub_Control/bin/Release/Pub_Class.dll
index 02c8a1d..b1e99a9 100644
--- a/Pub_Control/bin/Release/Pub_Class.dll
+++ b/Pub_Control/bin/Release/Pub_Class.dll
Binary files differ
diff --git a/Pub_Control/bin/Release/Pub_Class.pdb b/Pub_Control/bin/Release/Pub_Class.pdb
index 1ac7450..e80c2b9 100644
--- a/Pub_Control/bin/Release/Pub_Class.pdb
+++ b/Pub_Control/bin/Release/Pub_Class.pdb
Binary files differ
diff --git a/Pub_Control/bin/Release/Pub_Control.dll b/Pub_Control/bin/Release/Pub_Control.dll
index a887c85..bf24be6 100644
--- a/Pub_Control/bin/Release/Pub_Control.dll
+++ b/Pub_Control/bin/Release/Pub_Control.dll
Binary files differ
diff --git a/Pub_Control/bin/Release/Pub_Control.pdb b/Pub_Control/bin/Release/Pub_Control.pdb
index 4aa1260..d6e00c4 100644
--- a/Pub_Control/bin/Release/Pub_Control.pdb
+++ b/Pub_Control/bin/Release/Pub_Control.pdb
Binary files differ
diff --git a/SQLHelper/bin/Release/Pub_Class.dll b/SQLHelper/bin/Release/Pub_Class.dll
index 02c8a1d..b1e99a9 100644
--- a/SQLHelper/bin/Release/Pub_Class.dll
+++ b/SQLHelper/bin/Release/Pub_Class.dll
Binary files differ
diff --git a/SQLHelper/bin/Release/Pub_Class.pdb b/SQLHelper/bin/Release/Pub_Class.pdb
index 1ac7450..e80c2b9 100644
--- a/SQLHelper/bin/Release/Pub_Class.pdb
+++ b/SQLHelper/bin/Release/Pub_Class.pdb
Binary files differ
diff --git a/SyntacticSugar/bin/Debug/SyntacticSugar.dll b/SyntacticSugar/bin/Debug/SyntacticSugar.dll
index a7e7f70..c1cb681 100644
--- a/SyntacticSugar/bin/Debug/SyntacticSugar.dll
+++ b/SyntacticSugar/bin/Debug/SyntacticSugar.dll
Binary files differ
diff --git a/SyntacticSugar/bin/Debug/SyntacticSugar.pdb b/SyntacticSugar/bin/Debug/SyntacticSugar.pdb
index 75e66e8..d4f984c 100644
--- a/SyntacticSugar/bin/Debug/SyntacticSugar.pdb
+++ b/SyntacticSugar/bin/Debug/SyntacticSugar.pdb
Binary files differ
diff --git a/SyntacticSugar/obj/Debug/SyntacticSugar.csproj.AssemblyReference.cache b/SyntacticSugar/obj/Debug/SyntacticSugar.csproj.AssemblyReference.cache
deleted file mode 100644
index fea44e6..0000000
--- a/SyntacticSugar/obj/Debug/SyntacticSugar.csproj.AssemblyReference.cache
+++ /dev/null
Binary files differ
diff --git a/SyntacticSugar/obj/Debug/SyntacticSugar.dll b/SyntacticSugar/obj/Debug/SyntacticSugar.dll
index a7e7f70..c1cb681 100644
--- a/SyntacticSugar/obj/Debug/SyntacticSugar.dll
+++ b/SyntacticSugar/obj/Debug/SyntacticSugar.dll
Binary files differ
diff --git a/SyntacticSugar/obj/Debug/SyntacticSugar.pdb b/SyntacticSugar/obj/Debug/SyntacticSugar.pdb
index 75e66e8..d4f984c 100644
--- a/SyntacticSugar/obj/Debug/SyntacticSugar.pdb
+++ b/SyntacticSugar/obj/Debug/SyntacticSugar.pdb
Binary files differ
diff --git a/WebAPI/Controllers/LMESController.cs b/WebAPI/Controllers/LMESController.cs
index e175fac..1887755 100644
--- a/WebAPI/Controllers/LMESController.cs
+++ b/WebAPI/Controllers/LMESController.cs
@@ -882,7 +882,6 @@
 
                             //鑷姩鐢熸垚宸ヤ綔鑱旂郴鍗�
                             ds2 = oCN.RunProcReturn("exec h_p_OA_WorkLinkBill_Create " + hSourceInterID + "," + 3772, "h_p_OA_WorkLinkBill_Create");
-  
                          }
                     }
                     oCN.RunProc("update Sc_ProcessExchangeBillSub set HSourceID=" + hSourceID + " where HInterID=" + hSourceInterID + " and HEntryID=" + hSourceEntryID);
diff --git a/WebAPI/Controllers/MJGL/Sc_MouldProdOutBillController.cs b/WebAPI/Controllers/MJGL/Sc_MouldProdOutBillController.cs
index 1ae2277..1fd5df6 100644
--- a/WebAPI/Controllers/MJGL/Sc_MouldProdOutBillController.cs
+++ b/WebAPI/Controllers/MJGL/Sc_MouldProdOutBillController.cs
@@ -29,7 +29,8 @@
         private json objJsonResult = new json();
         SQLHelper.ClsCN oCn = new SQLHelper.ClsCN();
         public DAL.ClsSc_MouldProdOutBill oBill = new DAL.ClsSc_MouldProdOutBill();
-
+        //鑾峰彇绯荤粺鍙傛暟
+        Pub_Class.ClsXt_SystemParameter oSystemParameter = new Pub_Class.ClsXt_SystemParameter();
 
         #region 鍣ㄥ叿棰嗙敤鍑哄簱鍗曞垎椤靛垪琛�
         [Route("Sc_MouldProdOutBillController/page")]
@@ -813,6 +814,26 @@
 
                 if (bResult)
                 {
+                    string sReturn = "";
+                    // 鍗庤垷 淇濆瓨鎴愬姛鍚庝笅鎺ㄥ伐浣滆仈绯诲崟 
+                    if (oSystemParameter.ShowBill(ref sReturn) == true)
+                    {
+                        if (oSystemParameter.omodel.WMS_CampanyName == "鍗庤垷")
+                        {
+                            //鑷姩鐢熸垚宸ヤ綔鑱旂郴鍗�
+                            var ds2 = oCn.RunProcReturn("exec h_p_OA_WorkLinkBill_Create " + oBill.omodel.HInterID + "," + 3802, "h_p_OA_WorkLinkBill_Create");
+
+                            if (ds2 != null && ds2.Tables[0].Rows.Count > 0)
+                            {
+                                int HInterID = int.Parse(ds2.Tables[0].Rows[0]["NewHInterID"].ToString());
+                                LogService.Write("鎵ц娑堟伅鎺ㄩ��..." + HInterID);
+
+                                // 瑙﹀彂娑堟伅鎺ㄩ��
+                                new SCGL.Sc_MESTransFerWorkBillController().AuditOA_WorkLinkBill(HInterID, 0, "admin");
+                            }
+                        }
+                    }
+
                     objJsonResult.code = "0";
                     objJsonResult.count = 1;
                     objJsonResult.Message = DBUtility.ClsPub.sExeReturnInfo;  //鎴愬姛锛�
diff --git a/WebAPI/Controllers/MJGL/Sc_MouldUpperBillController.cs b/WebAPI/Controllers/MJGL/Sc_MouldUpperBillController.cs
index 9db9f64..1639cc9 100644
--- a/WebAPI/Controllers/MJGL/Sc_MouldUpperBillController.cs
+++ b/WebAPI/Controllers/MJGL/Sc_MouldUpperBillController.cs
@@ -2447,7 +2447,16 @@
                     if (oSystemParameter.omodel.WMS_CampanyName == "鍗庤垷")
                     {
                         //鑷姩鐢熸垚宸ヤ綔鑱旂郴鍗�
-                        oCN.RunProc("exec h_p_OA_WorkLinkBill_Create " + HInterID + "," + 3847);
+                        var ds2 = oCN.RunProcReturn("exec h_p_OA_WorkLinkBill_Create " + BillOld.omodel.HInterID + "," + 3847, "h_p_OA_WorkLinkBill_Create");
+
+                        if (ds2 != null && ds2.Tables[0].Rows.Count > 0)
+                        {
+                            int HInterID0 = int.Parse(ds2.Tables[0].Rows[0]["NewHInterID"].ToString());
+                            LogService.Write("鎵ц娑堟伅鎺ㄩ��..." + HInterID);
+
+                            // 瑙﹀彂娑堟伅鎺ㄩ��
+                            new SCGL.Sc_MESTransFerWorkBillController().AuditOA_WorkLinkBill(HInterID0, 0, "admin");
+                        }
                     }                   
                 }
              
diff --git "a/WebAPI/Controllers/\345\223\201\350\264\250\347\256\241\347\220\206/\345\267\241\346\243\200\345\215\225/QC_PatrolProcCheckOtherBillController.cs" "b/WebAPI/Controllers/\345\223\201\350\264\250\347\256\241\347\220\206/\345\267\241\346\243\200\345\215\225/QC_PatrolProcCheckOtherBillController.cs"
index c0f55d3..0ccb63d 100644
--- "a/WebAPI/Controllers/\345\223\201\350\264\250\347\256\241\347\220\206/\345\267\241\346\243\200\345\215\225/QC_PatrolProcCheckOtherBillController.cs"
+++ "b/WebAPI/Controllers/\345\223\201\350\264\250\347\256\241\347\220\206/\345\267\241\346\243\200\345\215\225/QC_PatrolProcCheckOtherBillController.cs"
@@ -7,6 +7,7 @@
 using System.Data;
 using System.Data.SqlClient;
 using System.Web.Http;
+using WebAPI.Controllers.SCGL;
 using WebAPI.Models;
 
 namespace WebAPI.Controllers
@@ -340,6 +341,27 @@
                 //鎻愮ず
                 if (bResult == true)
                 {
+                    string sReturn = "";
+                    // 鍗庤垷 淇濆瓨鎴愬姛鍚庝笅鎺ㄥ伐浣滆仈绯诲崟 
+                    if (oSystemParameter.ShowBill(ref sReturn) == true)
+                    {
+                        if (oSystemParameter.omodel.WMS_CampanyName == "鍗庤垷")
+                        {
+                            //鑷姩鐢熸垚宸ヤ綔鑱旂郴鍗�
+                            var ds2 = oCN.RunProcReturn("exec h_p_OA_WorkLinkBill_Create " + BillOld.omodel.HInterID + "," + 7507, "h_p_OA_WorkLinkBill_Create");
+
+                            if (ds2 != null && ds2.Tables[0].Rows.Count > 0)
+                            {
+                                int HInterID = int.Parse(ds2.Tables[0].Rows[0]["NewHInterID"].ToString());
+                                LogService.Write("鎵ц娑堟伅鎺ㄩ��..." + HInterID);
+
+                                // 瑙﹀彂娑堟伅鎺ㄩ��
+                                new Sc_MESTransFerWorkBillController().AuditOA_WorkLinkBill(HInterID, 0, user);
+                            }
+                        }
+                    }
+
+
                     objJsonResult.code = "1";
                     objJsonResult.count = 1;
                     objJsonResult.Message = ClsPub.sExeReturnInfo+"鍗曟嵁鍙�:" + mainList[0].HBillNo.Trim();
diff --git "a/WebAPI/Controllers/\345\223\201\350\264\250\347\256\241\347\220\206/\345\267\245\345\272\217\346\243\200\351\252\214\345\215\225/QC_ProcessCheckBillController.cs" "b/WebAPI/Controllers/\345\223\201\350\264\250\347\256\241\347\220\206/\345\267\245\345\272\217\346\243\200\351\252\214\345\215\225/QC_ProcessCheckBillController.cs"
index f718c0b..c9cd240 100644
--- "a/WebAPI/Controllers/\345\223\201\350\264\250\347\256\241\347\220\206/\345\267\245\345\272\217\346\243\200\351\252\214\345\215\225/QC_ProcessCheckBillController.cs"
+++ "b/WebAPI/Controllers/\345\223\201\350\264\250\347\256\241\347\220\206/\345\267\245\345\272\217\346\243\200\351\252\214\345\215\225/QC_ProcessCheckBillController.cs"
@@ -1049,6 +1049,26 @@
                 //鎻愮ず
                 if (bResult == true)
                 {
+                    string sReturn = "";
+                    // 鍗庤垷 淇濆瓨鎴愬姛鍚庝笅鎺ㄥ伐浣滆仈绯诲崟 
+                    if (oSystemParameter.ShowBill(ref sReturn) == true)
+                    {
+                        if (oSystemParameter.omodel.WMS_CampanyName == "鍗庤垷")
+                        {
+                            //鑷姩鐢熸垚宸ヤ綔鑱旂郴鍗�
+                            var ds2 = oCN.RunProcReturn("exec h_p_OA_WorkLinkBill_Create " + BillOld.omodel.HInterID + "," + 7520, "h_p_OA_WorkLinkBill_Create");
+
+                            if (ds2 != null && ds2.Tables[0].Rows.Count > 0)
+                            {
+                                int HInterID = int.Parse(ds2.Tables[0].Rows[0]["NewHInterID"].ToString());
+                                LogService.Write("鎵ц娑堟伅鎺ㄩ��..." + HInterID);
+
+                                // 瑙﹀彂娑堟伅鎺ㄩ��
+                                new SCGL.Sc_MESTransFerWorkBillController().AuditOA_WorkLinkBill(HInterID, 0, user);
+                            }
+                        }
+                    }
+
                     objJsonResult.code = "1";
                     objJsonResult.count = 1;
                     objJsonResult.Message = ClsPub.sExeReturnInfo+"鍗曟嵁鍙�:" + mainList[0].HBillNo.Trim();
diff --git "a/WebAPI/Controllers/\345\223\201\350\264\250\347\256\241\347\220\206/\346\243\200\351\252\214\345\217\226\346\240\267\350\277\230\346\240\267\345\215\225/QC_TakeSampleCheckBillController.cs" "b/WebAPI/Controllers/\345\223\201\350\264\250\347\256\241\347\220\206/\346\243\200\351\252\214\345\217\226\346\240\267\350\277\230\346\240\267\345\215\225/QC_TakeSampleCheckBillController.cs"
index 4aba94e..73114bc 100644
--- "a/WebAPI/Controllers/\345\223\201\350\264\250\347\256\241\347\220\206/\346\243\200\351\252\214\345\217\226\346\240\267\350\277\230\346\240\267\345\215\225/QC_TakeSampleCheckBillController.cs"
+++ "b/WebAPI/Controllers/\345\223\201\350\264\250\347\256\241\347\220\206/\346\243\200\351\252\214\345\217\226\346\240\267\350\277\230\346\240\267\345\215\225/QC_TakeSampleCheckBillController.cs"
@@ -8,6 +8,7 @@
 using System.Data;
 using System.Data.SqlClient;
 using System.Web.Http;
+using WebAPI.Controllers.SCGL;
 using WebAPI.Models;
 
 namespace WebAPI.Controllers
@@ -267,7 +268,16 @@
                         if (oSystemParameter.omodel.WMS_CampanyName == "鍗庤垷")
                         {
                             //鑷姩鐢熸垚宸ヤ綔鑱旂郴鍗�
-                            oCN.RunProc("exec h_p_OA_WorkLinkBill_Create " + BillOld.omodel.HInterID + "," + 7521);
+                            var ds2 = oCN.RunProcReturn("exec h_p_OA_WorkLinkBill_Create " + BillOld.omodel.HInterID + "," + 7521, "h_p_OA_WorkLinkBill_Create");
+
+                            if (ds2 != null && ds2.Tables[0].Rows.Count > 0)
+                            {
+                                int HInterID = int.Parse(ds2.Tables[0].Rows[0]["NewHInterID"].ToString());
+                                LogService.Write("鎵ц娑堟伅鎺ㄩ��..." + HInterID);
+
+                                // 瑙﹀彂娑堟伅鎺ㄩ��
+                                new Sc_MESTransFerWorkBillController().AuditOA_WorkLinkBill(HInterID, 0, msg4);
+                            }
                         }
                     }
                 }
diff --git "a/WebAPI/Controllers/\345\223\201\350\264\250\347\256\241\347\220\206/\351\246\226\344\273\266\346\243\200\351\252\214\345\215\225/QC_FirstPieceCheckBillController.cs" "b/WebAPI/Controllers/\345\223\201\350\264\250\347\256\241\347\220\206/\351\246\226\344\273\266\346\243\200\351\252\214\345\215\225/QC_FirstPieceCheckBillController.cs"
index fef7878..39ef1fe 100644
--- "a/WebAPI/Controllers/\345\223\201\350\264\250\347\256\241\347\220\206/\351\246\226\344\273\266\346\243\200\351\252\214\345\215\225/QC_FirstPieceCheckBillController.cs"
+++ "b/WebAPI/Controllers/\345\223\201\350\264\250\347\256\241\347\220\206/\351\246\226\344\273\266\346\243\200\351\252\214\345\215\225/QC_FirstPieceCheckBillController.cs"
@@ -417,10 +417,17 @@
                             if (ds2 != null && ds2.Tables[0].Rows.Count > 0)
                             {
                                 int HInterID = int.Parse(ds2.Tables[0].Rows[0]["NewHInterID"].ToString());
-                                LogService.Write("鎵ц娑堟伅鎺ㄩ��..." + HInterID);
 
-                                // 瑙﹀彂娑堟伅鎺ㄩ��
-                                new Sc_MESTransFerWorkBillController().AuditOA_WorkLinkBill(HInterID, 0, user);
+                                if (oSystemParameter.ShowBill(ref sReturn) == true)
+                                {
+                                    if (oSystemParameter.omodel.WMS_CampanyName == "鍗庤垷")
+                                    {
+                                        LogService.Write("鎵ц娑堟伅鎺ㄩ��..." + HInterID);
+
+                                        // 瑙﹀彂娑堟伅鎺ㄩ��
+                                        new Sc_MESTransFerWorkBillController().AuditOA_WorkLinkBill(HInterID, 0, user);
+                                    }
+                                }
                             }
                         }
                     }                    
diff --git "a/WebAPI/Controllers/\346\235\241\347\240\201\347\256\241\347\220\206/WEBSController.cs" "b/WebAPI/Controllers/\346\235\241\347\240\201\347\256\241\347\220\206/WEBSController.cs"
index ad53efc..b7e29da 100644
--- "a/WebAPI/Controllers/\346\235\241\347\240\201\347\256\241\347\220\206/WEBSController.cs"
+++ "b/WebAPI/Controllers/\346\235\241\347\240\201\347\256\241\347\220\206/WEBSController.cs"
@@ -14135,6 +14135,25 @@
                     return objJsonResult;
                 }
 
+                if (oSystemParameter.omodel.WMS_CampanyName == "鍗庤垷")
+                {
+                    if (HBillType == 7507) // 鍗曟嵁绫诲瀷鏄湯浠舵楠屽崟 鏌ユ壘鍗曟嵁鏄惁閲嶅锛屾楠屾槸鍚﹀悎鏍硷紝鍗曟嵁閲嶅闇�瑕佽繑鍥炰笉鍚岀殑鐘舵��
+                    {
+                        var ds2 = oCn.RunProcReturn($"select top 1 * from QC_ProcessCheckBillMain where HMainSourceBillNo = '{HBarCode}' order by HDate desc", "QC_ProcessCheckBillMain");
+                        if(ds2.Tables[0].Rows.Count > 0)
+                        {
+                            if (ds2.Tables[0].Rows[0]["HCheckerResult"].ToString() == "true") // 妫�楠屽悎鏍兼彁绀烘槸鍚﹂渶瑕佹柊澧�
+                            {
+                                objJsonResult.code = "2"; // 杩斿洖Code涓�2琛ㄧず鍗曟嵁閲嶅锛岄渶瑕佹彁绀烘槸鍚﹂渶瑕佹柊澧炲崟鎹�
+                                objJsonResult.count = 1;
+                                objJsonResult.Message = "success锛�";
+                                objJsonResult.data = ds.Tables[0];
+                                return objJsonResult;
+                            }
+                        }
+                    }
+                }
+
                 objJsonResult.code = "1";
                 objJsonResult.count = 1;
                 objJsonResult.Message = "success锛�";
diff --git a/WebAPI/Properties/PublishProfiles/FolderProfile4.pubxml.user b/WebAPI/Properties/PublishProfiles/FolderProfile4.pubxml.user
index 15e06dc..3a4bbcf 100644
--- a/WebAPI/Properties/PublishProfiles/FolderProfile4.pubxml.user
+++ b/WebAPI/Properties/PublishProfiles/FolderProfile4.pubxml.user
@@ -5,7 +5,7 @@
 <Project ToolsVersion="4.0" xmlns="http://schemas.microsoft.com/developer/msbuild/2003">
   <PropertyGroup>
     <_PublishTargetUrl>D:\缃戠珯鍙戝竷\鏅轰簯MESWMS\API</_PublishTargetUrl>
-    <History>True|2026-02-11T03:45:25.6746436Z;True|2026-02-11T11:44:47.3185555+08:00;True|2026-02-11T10:54:59.0679758+08:00;True|2026-02-11T10:43:35.2341241+08:00;True|2026-02-11T10:36:26.6768242+08:00;True|2026-02-11T10:26:54.7470684+08:00;True|2026-02-11T10:26:14.5696000+08:00;True|2026-02-11T10:19:17.3267746+08:00;True|2026-02-11T10:03:08.9096446+08:00;True|2026-02-11T10:00:03.1731421+08:00;False|2026-02-11T09:58:47.2916714+08:00;True|2026-02-10T15:11:02.0203382+08:00;True|2026-02-10T15:07:21.6761915+08:00;True|2026-02-10T14:56:44.3660951+08:00;True|2026-02-10T14:42:24.1573010+08:00;True|2026-02-10T14:17:49.6012996+08:00;True|2026-02-10T10:54:27.8849732+08:00;True|2026-02-10T10:37:09.4615737+08:00;True|2026-02-10T10:32:50.2882198+08:00;True|2026-02-10T10:16:38.5004114+08:00;True|2026-02-10T10:04:58.3653257+08:00;False|2026-02-10T10:04:05.6938724+08:00;True|2026-02-09T11:58:12.9122757+08:00;True|2026-02-09T11:52:51.2402774+08:00;True|2026-02-09T11:47:15.5230979+08:00;True|2026-02-09T10:53:15.6587025+08:00;False|2026-02-09T10:52:01.4586729+08:00;True|2026-02-05T12:04:14.1139398+08:00;True|2026-02-05T10:00:41.8883921+08:00;False|2026-02-05T09:59:49.2086159+08:00;True|2026-02-04T13:30:53.8564398+08:00;True|2026-02-04T13:30:06.5486103+08:00;True|2026-02-04T13:21:44.7322601+08:00;True|2026-02-04T13:15:45.0093895+08:00;True|2026-02-04T13:06:30.4891537+08:00;False|2026-02-04T13:05:35.5287589+08:00;True|2026-02-04T12:39:42.2682329+08:00;True|2026-02-04T12:21:52.9722100+08:00;True|2026-02-04T12:16:07.8303016+08:00;True|2026-02-04T12:08:43.8268899+08:00;True|2026-02-04T12:03:26.1174616+08:00;True|2026-02-04T10:33:15.5394044+08:00;False|2026-02-04T10:32:30.7038502+08:00;True|2026-02-02T15:42:04.9554792+08:00;True|2026-02-02T15:39:28.7017318+08:00;True|2026-02-02T15:38:33.5592835+08:00;True|2026-02-02T15:34:24.8450917+08:00;True|2026-02-02T15:30:36.5990146+08:00;True|2026-02-02T15:09:46.1965065+08:00;True|2026-02-02T15:09:24.9794288+08:00;True|2026-02-02T15:05:46.0763516+08:00;True|2026-02-02T14:56:30.1210013+08:00;True|2026-02-02T14:52:50.7435709+08:00;True|2026-02-02T14:47:49.5891710+08:00;True|2026-02-02T14:43:23.0006294+08:00;True|2026-02-02T14:31:10.1220612+08:00;True|2026-02-02T14:21:15.6540317+08:00;True|2026-02-02T14:15:41.6183116+08:00;True|2026-02-02T14:11:32.1234982+08:00;True|2026-02-02T14:01:34.6298901+08:00;True|2026-02-02T13:55:03.4760402+08:00;True|2026-02-02T13:49:00.0420220+08:00;True|2026-02-02T13:17:17.0678676+08:00;False|2026-02-02T13:15:46.0360589+08:00;False|2026-02-02T13:15:27.1689505+08:00;False|2026-02-02T13:14:27.3078641+08:00;True|2026-02-02T12:55:41.9272586+08:00;True|2026-02-02T12:55:22.0826476+08:00;True|2026-02-02T12:09:21.8247404+08:00;True|2026-02-02T12:03:58.9256304+08:00;True|2026-02-02T11:56:01.5744871+08:00;True|2026-02-02T11:42:30.2218073+08:00;True|2026-02-02T10:59:29.6077968+08:00;False|2026-02-02T10:59:08.7803594+08:00;True|2026-01-29T14:40:47.4658031+08:00;True|2026-01-29T14:36:18.2141550+08:00;True|2026-01-29T14:32:52.4872179+08:00;True|2026-01-29T14:32:06.4197291+08:00;True|2026-01-29T14:09:33.9372276+08:00;True|2026-01-29T14:08:17.6503129+08:00;True|2026-01-29T14:06:27.5784162+08:00;True|2026-01-29T13:10:48.6581055+08:00;True|2026-01-29T13:07:28.5589276+08:00;True|2026-01-29T12:44:24.3707488+08:00;True|2026-01-29T12:42:34.6204068+08:00;True|2026-01-29T12:39:55.3867683+08:00;True|2026-01-29T12:29:41.8565928+08:00;True|2026-01-29T12:17:04.5932345+08:00;True|2026-01-29T10:08:23.4550691+08:00;True|2026-01-29T10:04:05.4236307+08:00;False|2026-01-29T10:03:18.4044168+08:00;True|2026-01-28T16:00:38.3698743+08:00;True|2026-01-28T14:15:04.1203132+08:00;True|2026-01-28T14:03:32.3230252+08:00;False|2026-01-28T14:02:41.6157812+08:00;True|2026-01-28T13:18:24.5590390+08:00;True|2026-01-28T13:10:49.5716734+08:00;True|2026-01-28T12:25:03.3201915+08:00;True|2026-01-28T12:24:37.6029904+08:00;True|2026-01-28T12:16:13.3862190+08:00;True|2026-01-28T11:43:57.8268938+08:00;True|2026-01-28T10:57:22.9246991+08:00;True|2026-01-28T10:49:34.6185686+08:00;True|2026-01-28T10:44:07.6308515+08:00;True|2026-01-28T10:36:00.0391721+08:00;True|2026-01-28T10:27:26.1658915+08:00;False|2026-01-28T10:27:00.5898601+08:00;True|2026-01-27T15:02:41.1819512+08:00;True|2026-01-27T14:55:32.3962262+08:00;True|2026-01-27T14:31:09.0105130+08:00;True|2026-01-27T13:19:08.8705541+08:00;True|2026-01-27T11:43:17.0109305+08:00;True|2026-01-27T10:53:13.5941761+08:00;True|2026-01-27T10:49:18.5740094+08:00;True|2026-01-27T10:43:29.4337654+08:00;True|2026-01-27T10:00:49.1779297+08:00;False|2026-01-27T10:00:34.2083888+08:00;True|2026-01-26T16:29:09.5100352+08:00;False|2026-01-26T16:29:04.6554601+08:00;False|2026-01-26T14:39:05.7640208+08:00;True|2026-01-26T09:57:23.8775907+08:00;False|2026-01-26T09:56:43.8599383+08:00;True|2026-01-26T09:37:16.8828589+08:00;False|2026-01-26T09:36:35.9597492+08:00;True|2026-01-25T15:20:11.0096169+08:00;True|2026-01-25T14:52:25.7167654+08:00;True|2026-01-25T14:28:16.6779637+08:00;False|2026-01-25T14:27:32.6753765+08:00;True|2026-01-23T16:17:17.9227805+08:00;True|2026-01-23T14:37:25.7929932+08:00;True|2026-01-23T14:32:25.7611106+08:00;False|2026-01-23T14:31:28.4811198+08:00;True|2026-01-22T09:55:07.0908298+08:00;True|2026-01-22T09:38:49.9102490+08:00;False|2026-01-22T09:37:53.0384929+08:00;True|2026-01-21T16:50:27.5625267+08:00;True|2026-01-21T10:50:18.7634322+08:00;True|2026-01-21T10:47:56.7913811+08:00;True|2026-01-21T10:41:46.5883817+08:00;True|2026-01-21T09:29:22.5824101+08:00;False|2026-01-21T09:28:13.4362586+08:00;True|2026-01-20T14:26:36.7806712+08:00;True|2026-01-20T13:13:01.3064754+08:00;False|2026-01-20T13:12:08.1800841+08:00;True|2026-01-20T10:28:19.5250951+08:00;True|2026-01-20T10:27:41.5947282+08:00;True|2026-01-20T10:23:10.6474490+08:00;True|2026-01-20T10:07:24.8412652+08:00;True|2026-01-20T09:53:19.8583529+08:00;True|2026-01-20T08:21:20.5302494+08:00;False|2026-01-20T08:20:24.6093320+08:00;True|2026-01-19T15:58:34.1439056+08:00;True|2026-01-19T15:56:47.6488483+08:00;True|2026-01-19T15:12:36.9286562+08:00;True|2026-01-19T14:55:17.2807312+08:00;True|2026-01-19T14:47:03.8892836+08:00;True|2026-01-19T14:36:15.0507410+08:00;True|2026-01-19T14:26:05.5060287+08:00;True|2026-01-19T13:50:54.8654304+08:00;True|2026-01-19T13:37:47.2294303+08:00;True|2026-01-19T13:20:13.3781676+08:00;True|2026-01-19T13:07:18.8111360+08:00;True|2026-01-19T13:01:15.1432453+08:00;True|2026-01-19T11:54:26.6582081+08:00;True|2026-01-19T11:23:28.6100843+08:00;True|2026-01-19T08:41:23.8724527+08:00;True|2026-01-19T08:34:06.3247836+08:00;True|2026-01-19T07:48:11.5052413+08:00;False|2026-01-19T07:47:21.4586297+08:00;True|2026-01-18T14:27:24.9640228+08:00;True|2026-01-18T13:21:44.9690334+08:00;False|2026-01-18T13:20:08.6314025+08:00;False|2026-01-16T16:53:24.3290896+08:00;True|2026-01-16T09:03:14.4122067+08:00;True|2026-01-16T08:44:23.0342932+08:00;False|2026-01-16T08:43:34.3488415+08:00;True|2026-01-15T16:27:10.8480719+08:00;False|2026-01-15T16:26:06.6002625+08:00;True|2026-01-15T13:04:43.0602637+08:00;</History>
+    <History>True|2026-02-24T02:25:01.2146652Z;True|2026-02-24T10:16:06.3505078+08:00;True|2026-02-24T10:08:41.7064926+08:00;False|2026-02-24T10:07:25.4868308+08:00;True|2026-02-21T14:56:37.2206752+08:00;True|2026-02-21T14:53:44.6277903+08:00;True|2026-02-21T14:40:10.4687091+08:00;False|2026-02-21T14:39:13.1736140+08:00;True|2026-02-11T11:45:25.6746436+08:00;True|2026-02-11T11:44:47.3185555+08:00;True|2026-02-11T10:54:59.0679758+08:00;True|2026-02-11T10:43:35.2341241+08:00;True|2026-02-11T10:36:26.6768242+08:00;True|2026-02-11T10:26:54.7470684+08:00;True|2026-02-11T10:26:14.5696000+08:00;True|2026-02-11T10:19:17.3267746+08:00;True|2026-02-11T10:03:08.9096446+08:00;True|2026-02-11T10:00:03.1731421+08:00;False|2026-02-11T09:58:47.2916714+08:00;True|2026-02-10T15:11:02.0203382+08:00;True|2026-02-10T15:07:21.6761915+08:00;True|2026-02-10T14:56:44.3660951+08:00;True|2026-02-10T14:42:24.1573010+08:00;True|2026-02-10T14:17:49.6012996+08:00;True|2026-02-10T10:54:27.8849732+08:00;True|2026-02-10T10:37:09.4615737+08:00;True|2026-02-10T10:32:50.2882198+08:00;True|2026-02-10T10:16:38.5004114+08:00;True|2026-02-10T10:04:58.3653257+08:00;False|2026-02-10T10:04:05.6938724+08:00;True|2026-02-09T11:58:12.9122757+08:00;True|2026-02-09T11:52:51.2402774+08:00;True|2026-02-09T11:47:15.5230979+08:00;True|2026-02-09T10:53:15.6587025+08:00;False|2026-02-09T10:52:01.4586729+08:00;True|2026-02-05T12:04:14.1139398+08:00;True|2026-02-05T10:00:41.8883921+08:00;False|2026-02-05T09:59:49.2086159+08:00;True|2026-02-04T13:30:53.8564398+08:00;True|2026-02-04T13:30:06.5486103+08:00;True|2026-02-04T13:21:44.7322601+08:00;True|2026-02-04T13:15:45.0093895+08:00;True|2026-02-04T13:06:30.4891537+08:00;False|2026-02-04T13:05:35.5287589+08:00;True|2026-02-04T12:39:42.2682329+08:00;True|2026-02-04T12:21:52.9722100+08:00;True|2026-02-04T12:16:07.8303016+08:00;True|2026-02-04T12:08:43.8268899+08:00;True|2026-02-04T12:03:26.1174616+08:00;True|2026-02-04T10:33:15.5394044+08:00;False|2026-02-04T10:32:30.7038502+08:00;True|2026-02-02T15:42:04.9554792+08:00;True|2026-02-02T15:39:28.7017318+08:00;True|2026-02-02T15:38:33.5592835+08:00;True|2026-02-02T15:34:24.8450917+08:00;True|2026-02-02T15:30:36.5990146+08:00;True|2026-02-02T15:09:46.1965065+08:00;True|2026-02-02T15:09:24.9794288+08:00;True|2026-02-02T15:05:46.0763516+08:00;True|2026-02-02T14:56:30.1210013+08:00;True|2026-02-02T14:52:50.7435709+08:00;True|2026-02-02T14:47:49.5891710+08:00;True|2026-02-02T14:43:23.0006294+08:00;True|2026-02-02T14:31:10.1220612+08:00;True|2026-02-02T14:21:15.6540317+08:00;True|2026-02-02T14:15:41.6183116+08:00;True|2026-02-02T14:11:32.1234982+08:00;True|2026-02-02T14:01:34.6298901+08:00;True|2026-02-02T13:55:03.4760402+08:00;True|2026-02-02T13:49:00.0420220+08:00;True|2026-02-02T13:17:17.0678676+08:00;False|2026-02-02T13:15:46.0360589+08:00;False|2026-02-02T13:15:27.1689505+08:00;False|2026-02-02T13:14:27.3078641+08:00;True|2026-02-02T12:55:41.9272586+08:00;True|2026-02-02T12:55:22.0826476+08:00;True|2026-02-02T12:09:21.8247404+08:00;True|2026-02-02T12:03:58.9256304+08:00;True|2026-02-02T11:56:01.5744871+08:00;True|2026-02-02T11:42:30.2218073+08:00;True|2026-02-02T10:59:29.6077968+08:00;False|2026-02-02T10:59:08.7803594+08:00;True|2026-01-29T14:40:47.4658031+08:00;True|2026-01-29T14:36:18.2141550+08:00;True|2026-01-29T14:32:52.4872179+08:00;True|2026-01-29T14:32:06.4197291+08:00;True|2026-01-29T14:09:33.9372276+08:00;True|2026-01-29T14:08:17.6503129+08:00;True|2026-01-29T14:06:27.5784162+08:00;True|2026-01-29T13:10:48.6581055+08:00;True|2026-01-29T13:07:28.5589276+08:00;True|2026-01-29T12:44:24.3707488+08:00;True|2026-01-29T12:42:34.6204068+08:00;True|2026-01-29T12:39:55.3867683+08:00;True|2026-01-29T12:29:41.8565928+08:00;True|2026-01-29T12:17:04.5932345+08:00;True|2026-01-29T10:08:23.4550691+08:00;True|2026-01-29T10:04:05.4236307+08:00;False|2026-01-29T10:03:18.4044168+08:00;True|2026-01-28T16:00:38.3698743+08:00;True|2026-01-28T14:15:04.1203132+08:00;True|2026-01-28T14:03:32.3230252+08:00;False|2026-01-28T14:02:41.6157812+08:00;True|2026-01-28T13:18:24.5590390+08:00;True|2026-01-28T13:10:49.5716734+08:00;True|2026-01-28T12:25:03.3201915+08:00;True|2026-01-28T12:24:37.6029904+08:00;True|2026-01-28T12:16:13.3862190+08:00;True|2026-01-28T11:43:57.8268938+08:00;True|2026-01-28T10:57:22.9246991+08:00;True|2026-01-28T10:49:34.6185686+08:00;True|2026-01-28T10:44:07.6308515+08:00;True|2026-01-28T10:36:00.0391721+08:00;True|2026-01-28T10:27:26.1658915+08:00;False|2026-01-28T10:27:00.5898601+08:00;True|2026-01-27T15:02:41.1819512+08:00;True|2026-01-27T14:55:32.3962262+08:00;True|2026-01-27T14:31:09.0105130+08:00;True|2026-01-27T13:19:08.8705541+08:00;True|2026-01-27T11:43:17.0109305+08:00;True|2026-01-27T10:53:13.5941761+08:00;True|2026-01-27T10:49:18.5740094+08:00;True|2026-01-27T10:43:29.4337654+08:00;True|2026-01-27T10:00:49.1779297+08:00;False|2026-01-27T10:00:34.2083888+08:00;True|2026-01-26T16:29:09.5100352+08:00;False|2026-01-26T16:29:04.6554601+08:00;False|2026-01-26T14:39:05.7640208+08:00;True|2026-01-26T09:57:23.8775907+08:00;False|2026-01-26T09:56:43.8599383+08:00;True|2026-01-26T09:37:16.8828589+08:00;False|2026-01-26T09:36:35.9597492+08:00;True|2026-01-25T15:20:11.0096169+08:00;True|2026-01-25T14:52:25.7167654+08:00;True|2026-01-25T14:28:16.6779637+08:00;False|2026-01-25T14:27:32.6753765+08:00;True|2026-01-23T16:17:17.9227805+08:00;True|2026-01-23T14:37:25.7929932+08:00;True|2026-01-23T14:32:25.7611106+08:00;False|2026-01-23T14:31:28.4811198+08:00;True|2026-01-22T09:55:07.0908298+08:00;True|2026-01-22T09:38:49.9102490+08:00;False|2026-01-22T09:37:53.0384929+08:00;True|2026-01-21T16:50:27.5625267+08:00;True|2026-01-21T10:50:18.7634322+08:00;True|2026-01-21T10:47:56.7913811+08:00;True|2026-01-21T10:41:46.5883817+08:00;True|2026-01-21T09:29:22.5824101+08:00;False|2026-01-21T09:28:13.4362586+08:00;True|2026-01-20T14:26:36.7806712+08:00;True|2026-01-20T13:13:01.3064754+08:00;False|2026-01-20T13:12:08.1800841+08:00;True|2026-01-20T10:28:19.5250951+08:00;True|2026-01-20T10:27:41.5947282+08:00;True|2026-01-20T10:23:10.6474490+08:00;True|2026-01-20T10:07:24.8412652+08:00;True|2026-01-20T09:53:19.8583529+08:00;True|2026-01-20T08:21:20.5302494+08:00;False|2026-01-20T08:20:24.6093320+08:00;True|2026-01-19T15:58:34.1439056+08:00;True|2026-01-19T15:56:47.6488483+08:00;True|2026-01-19T15:12:36.9286562+08:00;True|2026-01-19T14:55:17.2807312+08:00;True|2026-01-19T14:47:03.8892836+08:00;True|2026-01-19T14:36:15.0507410+08:00;True|2026-01-19T14:26:05.5060287+08:00;True|2026-01-19T13:50:54.8654304+08:00;True|2026-01-19T13:37:47.2294303+08:00;True|2026-01-19T13:20:13.3781676+08:00;True|2026-01-19T13:07:18.8111360+08:00;True|2026-01-19T13:01:15.1432453+08:00;True|2026-01-19T11:54:26.6582081+08:00;True|2026-01-19T11:23:28.6100843+08:00;True|2026-01-19T08:41:23.8724527+08:00;True|2026-01-19T08:34:06.3247836+08:00;True|2026-01-19T07:48:11.5052413+08:00;False|2026-01-19T07:47:21.4586297+08:00;True|2026-01-18T14:27:24.9640228+08:00;True|2026-01-18T13:21:44.9690334+08:00;False|2026-01-18T13:20:08.6314025+08:00;False|2026-01-16T16:53:24.3290896+08:00;True|2026-01-16T09:03:14.4122067+08:00;True|2026-01-16T08:44:23.0342932+08:00;False|2026-01-16T08:43:34.3488415+08:00;True|2026-01-15T16:27:10.8480719+08:00;False|2026-01-15T16:26:06.6002625+08:00;True|2026-01-15T13:04:43.0602637+08:00;</History>
   </PropertyGroup>
   <ItemGroup>
     <File Include="apiapp.json">
@@ -45,28 +45,28 @@
       <publishTime>02/22/2013 16:43:40</publishTime>
     </File>
     <File Include="bin/BLL.dll">
-      <publishTime>02/04/2026 13:29:36</publishTime>
+      <publishTime>02/21/2026 14:39:31</publishTime>
     </File>
     <File Include="bin/BLL.pdb">
-      <publishTime>02/04/2026 13:29:36</publishTime>
+      <publishTime>02/21/2026 14:39:31</publishTime>
     </File>
     <File Include="bin/BouncyCastle.Crypto.dll">
       <publishTime>12/18/2020 05:32:28</publishTime>
     </File>
     <File Include="bin/DAL.dll">
-      <publishTime>02/04/2026 13:29:33</publishTime>
+      <publishTime>02/21/2026 14:39:28</publishTime>
     </File>
     <File Include="bin/DAL.pdb">
-      <publishTime>02/04/2026 13:29:33</publishTime>
+      <publishTime>02/21/2026 14:39:28</publishTime>
     </File>
     <File Include="bin/Dapper.dll">
       <publishTime>07/22/2016 22:52:40</publishTime>
     </File>
     <File Include="bin/DBUtility.dll">
-      <publishTime>02/02/2026 15:17:51</publishTime>
+      <publishTime>02/21/2026 14:39:23</publishTime>
     </File>
     <File Include="bin/DBUtility.pdb">
-      <publishTime>02/02/2026 15:17:51</publishTime>
+      <publishTime>02/21/2026 14:39:23</publishTime>
     </File>
     <File Include="bin/Fleck.dll">
       <publishTime>04/22/2021 11:48:12</publishTime>
@@ -138,10 +138,10 @@
       <publishTime>07/25/2012 19:48:56</publishTime>
     </File>
     <File Include="bin/Model.dll">
-      <publishTime>02/04/2026 13:29:27</publishTime>
+      <publishTime>02/21/2026 14:39:24</publishTime>
     </File>
     <File Include="bin/Model.pdb">
-      <publishTime>02/04/2026 13:29:27</publishTime>
+      <publishTime>02/21/2026 14:39:24</publishTime>
     </File>
     <File Include="bin/Models/ClsSc_MouldScrapOutBillMain.cs">
       <publishTime>04/21/2025 11:46:16</publishTime>
@@ -192,10 +192,10 @@
       <publishTime>08/31/2012 06:22:50</publishTime>
     </File>
     <File Include="bin/SQLHelper.dll">
-      <publishTime>02/02/2026 15:17:50</publishTime>
+      <publishTime>02/11/2026 16:11:54</publishTime>
     </File>
     <File Include="bin/SQLHelper.pdb">
-      <publishTime>02/02/2026 15:17:50</publishTime>
+      <publishTime>02/11/2026 16:11:54</publishTime>
     </File>
     <File Include="bin/Swashbuckle.Core.dll">
       <publishTime>02/16/2015 01:57:08</publishTime>
@@ -324,13 +324,13 @@
       <publishTime>11/24/2014 19:18:48</publishTime>
     </File>
     <File Include="bin/WebAPI.dll">
-      <publishTime>02/11/2026 13:40:13</publishTime>
+      <publishTime>02/24/2026 10:24:30</publishTime>
     </File>
     <File Include="bin/WebAPI.pdb">
-      <publishTime>02/11/2026 13:40:13</publishTime>
+      <publishTime>02/24/2026 10:24:30</publishTime>
     </File>
     <File Include="bin/WebAPI.XmlSerializers.dll">
-      <publishTime>02/11/2026 13:40:24</publishTime>
+      <publishTime>02/24/2026 10:24:58</publishTime>
     </File>
     <File Include="bin/WebGrease.dll">
       <publishTime>07/18/2013 01:03:52</publishTime>
diff --git a/WebAPI/WebAPI.csproj.user b/WebAPI/WebAPI.csproj.user
index 1f0eb86..40e9ce9 100644
--- a/WebAPI/WebAPI.csproj.user
+++ b/WebAPI/WebAPI.csproj.user
@@ -1,7 +1,7 @@
 锘�<?xml version="1.0" encoding="utf-8"?>
 <Project ToolsVersion="Current" xmlns="http://schemas.microsoft.com/developer/msbuild/2003">
   <PropertyGroup>
-    <LastActiveSolutionConfig>Debug|x86</LastActiveSolutionConfig>
+    <LastActiveSolutionConfig>Release|Any CPU</LastActiveSolutionConfig>
     <UseIISExpress>true</UseIISExpress>
     <Use64BitIISExpress />
     <IISExpressSSLPort />
@@ -9,7 +9,7 @@
     <IISExpressWindowsAuthentication>disabled</IISExpressWindowsAuthentication>
     <IISExpressUseClassicPipelineMode>false</IISExpressUseClassicPipelineMode>
     <UseGlobalApplicationHostFile />
-    <NameOfLastUsedPublishProfile>D:\宸ヤ綔浠g爜\鏅轰簯杩堟�漒MES\MES-WEB-API\WebAPI\Properties\PublishProfiles\FolderProfile2.pubxml</NameOfLastUsedPublishProfile>
+    <NameOfLastUsedPublishProfile>D:\WorkBench\MES-WEB-API\WebAPI\Properties\PublishProfiles\FolderProfile4.pubxml</NameOfLastUsedPublishProfile>
     <ProjectView>ShowAllFiles</ProjectView>
   </PropertyGroup>
   <ProjectExtensions>
diff --git a/sdk_dingding/TopSdk/bin/Debug/TopSdk.dll b/sdk_dingding/TopSdk/bin/Debug/TopSdk.dll
index f09e2fe..b431a75 100644
--- a/sdk_dingding/TopSdk/bin/Debug/TopSdk.dll
+++ b/sdk_dingding/TopSdk/bin/Debug/TopSdk.dll
Binary files differ
diff --git a/sdk_dingding/TopSdk/bin/Debug/TopSdk.pdb b/sdk_dingding/TopSdk/bin/Debug/TopSdk.pdb
index f317ed0..28da228 100644
--- a/sdk_dingding/TopSdk/bin/Debug/TopSdk.pdb
+++ b/sdk_dingding/TopSdk/bin/Debug/TopSdk.pdb
Binary files differ
diff --git a/sdk_dingding/TopSdk/obj/Debug/TopSdk.csproj.AssemblyReference.cache b/sdk_dingding/TopSdk/obj/Debug/TopSdk.csproj.AssemblyReference.cache
deleted file mode 100644
index d77c332..0000000
--- a/sdk_dingding/TopSdk/obj/Debug/TopSdk.csproj.AssemblyReference.cache
+++ /dev/null
Binary files differ
diff --git a/sdk_dingding/TopSdk/obj/Debug/TopSdk.csproj.FileListAbsolute.txt b/sdk_dingding/TopSdk/obj/Debug/TopSdk.csproj.FileListAbsolute.txt
index 0c73fb9..5a4fbde 100644
--- a/sdk_dingding/TopSdk/obj/Debug/TopSdk.csproj.FileListAbsolute.txt
+++ b/sdk_dingding/TopSdk/obj/Debug/TopSdk.csproj.FileListAbsolute.txt
@@ -26,4 +26,3 @@
 D:\宸ヤ綔浠g爜\鏅轰簯杩堟�漒MES\MES-WEB-API\sdk_dingding\TopSdk\obj\Debug\TopSdk.csproj.CoreCompileInputs.cache
 D:\宸ヤ綔浠g爜\鏅轰簯杩堟�漒MES\MES-WEB-API\sdk_dingding\TopSdk\obj\Debug\TopSdk.dll
 D:\宸ヤ綔浠g爜\鏅轰簯杩堟�漒MES\MES-WEB-API\sdk_dingding\TopSdk\obj\Debug\TopSdk.pdb
-D:\WorkBench\MES-WEB-API\sdk_dingding\TopSdk\obj\Debug\TopSdk.csproj.AssemblyReference.cache
diff --git a/sdk_dingding/TopSdk/obj/Debug/TopSdk.dll b/sdk_dingding/TopSdk/obj/Debug/TopSdk.dll
index f09e2fe..b431a75 100644
--- a/sdk_dingding/TopSdk/obj/Debug/TopSdk.dll
+++ b/sdk_dingding/TopSdk/obj/Debug/TopSdk.dll
Binary files differ
diff --git a/sdk_dingding/TopSdk/obj/Debug/TopSdk.pdb b/sdk_dingding/TopSdk/obj/Debug/TopSdk.pdb
index f317ed0..28da228 100644
--- a/sdk_dingding/TopSdk/obj/Debug/TopSdk.pdb
+++ b/sdk_dingding/TopSdk/obj/Debug/TopSdk.pdb
Binary files differ

diff --git a/WebAPI/Controllers/Sc_ProcessMangementController.cs b/WebAPI/Controllers/Sc_ProcessMangementController.cs
index a6e8588..bae5563 100644
--- a/WebAPI/Controllers/Sc_ProcessMangementController.cs
+++ b/WebAPI/Controllers/Sc_ProcessMangementController.cs
@@ -1503,7 +1503,9 @@
                 FentityModel.Add("FBaseUnitId", new JObject() { ["Fnumber"] = HUnitNumber.ToString() });//鍩烘湰鍗曚綅
                 FentityModel.Add("FBaseInspectQty", HCheckQty.ToString());//鍩烘湰鍗曚綅妫�楠屾暟閲�
                 FentityModel.Add("FSupplierId", new JObject() { ["Fnumber"] = HSupNumber.ToString() }); //  渚涘簲鍟�
-                                                                                                        //FentityModel.Add("FStockId", new JObject() { ["Fnumber"] = HWHNumber.ToString() }); // 浠撳簱
+                
+                
+                // FentityModel.Add("FStockId", new JObject() { ["Fnumber"] = HWHID.ToString() }); // 浠撳簱
                 FentityModel.Add("FInspectTimes", "1"); // 妫�楠屾鏁� 
                 FentityModel.Add("FTimeUnit", "24");//鏃堕棿鍗曚綅
                 FentityModel.Add("FSAMPLEDAMAGEBEARER", "2");//鏍锋湰鐮村潖鎵挎媴鏂�
@@ -1767,10 +1769,31 @@
                 FentityModel.Add("FQCStatus", "1");//  璐ㄦ鐘舵�� 
                 FentityModel.Add("FIsRelated", false);//  涓嶈壇鍝佸叧鑱旀爣蹇�
                 FentityModel.Add("FSrcBillType0", "PUR_ReceiveBill");//  婧愬崟绫诲瀷
+                if (oSystemParameter.ShowBill(ref sErr))
+                {
+                    if (oSystemParameter.omodel.WMS_CampanyName == "閿﹂殕")
+                    {
+                        FentityModel.Add("FSrcBillNo0", HSLBillNo.ToString());    //鏀舵枡閫氱煡鍗曞崟鍙�
+                        FentityModel.Add("FSrcInterId0", HSLInterID.ToString());      //鏀舵枡閫氱煡鍗曚富ID
+                        FentityModel.Add("FSrcEntryId0", HSLEntryID.ToString());
+                        FentityModel.Add("FSrcEntrySeq0", HSLSeQ.ToString());    //婧愬崟琛屽彿
+
+                        FentityModel.Add("F_WPVT_Text_uky", HSourceBillNo.ToString());    //婧愬崟琛屽彿
+                        FentityModel.Add("F_WPVT_Integer_fg2", HSeQ.ToString());  //璁㈠崟琛屽彿
+                    }
+                }
                 FentityModel.Add("FBaseUnitId", new JObject() { ["Fnumber"] = HUnitNumber.ToString() });//鍩烘湰鍗曚綅
                 FentityModel.Add("FBaseInspectQty", HCheckQty.ToString());//鍩烘湰鍗曚綅妫�楠屾暟閲�
                 FentityModel.Add("FSupplierId", new JObject() { ["Fnumber"] = HSupNumber.ToString() }); //  渚涘簲鍟�
-                                                                                                        //FentityModel.Add("FStockId", new JObject() { ["Fnumber"] = HWHNumber.ToString() }); // 浠撳簱
+
+                if (oSystemParameter.ShowBill(ref sErr))
+                {
+                    if (oSystemParameter.omodel.WMS_CampanyName == "閿﹂殕")
+                    {
+                        FentityModel.Add("FStockId", new JObject() { ["Fnumber"] = HWHID.ToString() }); // 浠撳簱
+
+                    }
+                }
                 FentityModel.Add("FInspectTimes", "1"); // 妫�楠屾鏁� 
                 FentityModel.Add("FTimeUnit", "24");//鏃堕棿鍗曚綅
                 FentityModel.Add("FSAMPLEDAMAGEBEARER", "2");//鏍锋湰鐮村潖鎵挎媴鏂�
@@ -1789,7 +1812,7 @@
                 FentityModel2.Add("FBasePolicyQty", HRightQty.ToString() == "0" ? HBadQty.ToString() : HRightQty.ToString()); //鍩烘湰鍗曚綅鏁伴噺
                 FentityModel2.Add("FUsePolicy", HUseResult.ToString());   //浣跨敤鍐崇瓥
                 FentityModel2.Add("FIsCheck", false);   //鏄惁鎶芥
-                                                        // 閿﹂殕鍚敤涓嶈壇澶勭悊
+                // 閿﹂殕鍚敤涓嶈壇澶勭悊
                 if (oSystemParameter.ShowBill(ref sErr))
                 {
                     if (string.Equals(oSystemParameter.omodel.WMS_CampanyName, "閿﹂殕"))
--
Gitblit v1.9.1